{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "InterProScan: protein sequence classifier",
            "doc": "Version 5.21-60 can be downloaded here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToDownload\n\nDocumentation on how to run InterProScan 5 can be found here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToRun\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/Pfam",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3"
                            ]
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005829"
                            ],
                            "version": [
                                "5.21-60"
                            ],
                            "package": "interproscan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "id": "#InterProScan5.21-60.cwl/applications"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#InterProScan5.21-60.cwl/proteinFile"
                }
            ],
            "baseCommand": "interproscan.sh",
            "arguments": [
                {
                    "valueFrom": "i5_annotations",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "TSV",
                    "prefix": "--formats"
                },
                "--disable-precalc",
                "--goterms",
                "--pathways",
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tempdir"
                }
            ],
            "id": "#InterProScan5.21-60.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "i5_annotations"
                    },
                    "id": "#InterProScan5.21-60.cwl/i5Annotations"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "normalize to fasta",
            "doc": "normalizes input sequeces to FASTA with fixed number of sequence characters\nper line using esl-reformat from https://github.com/EddyRivasLab/easel\n",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#esl-reformat-replace.yaml/replace",
                            "label": "sequence token replacement",
                            "fields": [
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/find",
                                    "type": "string",
                                    "label": null,
                                    "doc": "Must be equal length with \"replace\". Each character from the input file\nwill be replaced by its counterpart (at the same position) from \"replace\"\n"
                                },
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/replace",
                                    "type": "string",
                                    "label": null,
                                    "doc": "must be equal length with \"find\""
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "#esl-reformat-replace.yaml/replace"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--replace",
                        "valueFrom": "$(self.find):$(self.replace)"
                    },
                    "id": "#esl-reformat.cwl/replace"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-reformat.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-reformat"
            ],
            "arguments": [
                {
                    "valueFrom": "fasta",
                    "position": 2
                }
            ],
            "stdout": "reformatted_sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-reformat.cwl/reformatted_sequences",
                    "outputBinding": {
                        "glob": "reformatted_sequences"
                    }
                }
            ],
            "id": "#esl-reformat.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005732"
                            ],
                            "version": [
                                "8d53bbce1ffe60d9aa3357c1001599f9a882317a"
                            ],
                            "package": "owltools"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-file"
                    },
                    "id": "#go_summary.cwl/InterProScan_results"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--config"
                    },
                    "id": "#go_summary.cwl/config"
                }
            ],
            "baseCommand": "go_summary_pipeline-1.0.py",
            "arguments": [
                {
                    "valueFrom": "go-summary",
                    "prefix": "--output-file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "go-summary"
                    },
                    "id": "#go_summary.cwl/go_summary"
                }
            ],
            "id": "#go_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "functional analysis prediction with InterProScan",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/go_summary_config"
                },
                {
                    "type": "File",
                    "id": "#main/predicted_CDS"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/functional_analysis/i5Annotations",
                    "id": "#main/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#main/summarize_with_GO/go_summary",
                    "id": "#main/go_summary"
                }
            ],
            "steps": [
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#InterProScan5.21-60.cwl",
                    "in": [
                        {
                            "default": [
                                "Pfam",
                                "TIGRFAM",
                                "PRINTS",
                                "ProSitePatterns",
                                "Gene3D"
                            ],
                            "id": "#main/functional_analysis/applications"
                        },
                        {
                            "source": "#main/remove_asterisks_and_reformat/reformatted_sequences",
                            "id": "#main/functional_analysis/proteinFile"
                        }
                    ],
                    "out": [
                        "#main/functional_analysis/i5Annotations"
                    ],
                    "id": "#main/functional_analysis"
                },
                {
                    "run": "#esl-reformat.cwl",
                    "in": [
                        {
                            "default": {
                                "find": "*",
                                "replace": "X"
                            },
                            "id": "#main/remove_asterisks_and_reformat/replace"
                        },
                        {
                            "source": "#main/predicted_CDS",
                            "id": "#main/remove_asterisks_and_reformat/sequences"
                        }
                    ],
                    "out": [
                        "#main/remove_asterisks_and_reformat/reformatted_sequences"
                    ],
                    "id": "#main/remove_asterisks_and_reformat"
                },
                {
                    "doc": "A summary of Gene Ontology (GO) terms derived from InterPro matches to\nthe sample. It is generated using a reduced list of GO terms called\nGO slim (http://www.geneontology.org/ontology/subsets/goslim_metagenomics.obo)\n",
                    "run": "#go_summary.cwl",
                    "in": [
                        {
                            "source": "#main/functional_analysis/i5Annotations",
                            "id": "#main/summarize_with_GO/InterProScan_results"
                        },
                        {
                            "source": "#main/go_summary_config",
                            "id": "#main/summarize_with_GO/config"
                        }
                    ],
                    "out": [
                        "#main/summarize_with_GO/go_summary"
                    ],
                    "id": "#main/summarize_with_GO"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
